pub struct TransferBatch {
pub operator: Address,
pub from: Address,
pub to: Address,
pub ids: Vec<U256>,
pub values: Vec<U256>,
}Expand description
Event with signature TransferBatch(address,address,address,uint256[],uint256[]) and selector 0x4a39dc06d4c0dbc64b70af90fd698a233a518aa5d07e595d983b8c0526c8f7fb.
event TransferBatch(address operator, address from, address to, uint256[] ids, uint256[] values);Fields
operator: Addressfrom: Addressto: Addressids: Vec<U256>values: Vec<U256>Trait Implementations
Sourceimpl Clone for TransferBatch
impl Clone for TransferBatch
Sourcefn clone(&self) -> TransferBatch
fn clone(&self) -> TransferBatch
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransferBatch
impl Debug for TransferBatch
Sourceimpl<'de> Deserialize<'de> for TransferBatch
impl<'de> Deserialize<'de> for TransferBatch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Emit for TransferBatch
impl Emit for TransferBatch
async fn emit( &self, queue: &Client, network: &NetworkKind, ) -> Result<(), PropagateError>
Sourceimpl Hash for TransferBatch
impl Hash for TransferBatch
Sourceimpl Insert for TransferBatch
impl Insert for TransferBatch
Sourceimpl PartialEq for TransferBatch
impl PartialEq for TransferBatch
Sourceimpl Serialize for TransferBatch
impl Serialize for TransferBatch
Sourceimpl SolEvent for TransferBatch
impl SolEvent for TransferBatch
Sourceconst SIGNATURE: &'static str = "TransferBatch(address,address,address,uint256[],uint256[])"
const SIGNATURE: &'static str = "TransferBatch(address,address,address,uint256[],uint256[])"
The event’s ABI signature. Read more
Sourceconst SIGNATURE_HASH: B256
const SIGNATURE_HASH: B256
The event’s ABI signature hash, or selector:
keccak256(SIGNATURE) Read moreSourcetype DataTuple<'a> = (Address, Address, Address, Array<Uint<256>>, Array<Uint<256>>)
type DataTuple<'a> = (Address, Address, Address, Array<Uint<256>>, Array<Uint<256>>)
The underlying tuple type which represents this event’s non-indexed
parameters. These parameters are ABI encoded and included in the log
body. Read more
Sourcetype DataToken<'a> = <<TransferBatch as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
type DataToken<'a> = <<TransferBatch as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
The
TokenSeq type corresponding to the tuple.Sourcetype TopicList = (FixedBytes<32>,)
type TopicList = (FixedBytes<32>,)
The underlying tuple type which represents this event’s topics. Read more
Sourcefn new(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Self
fn new( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Self
Convert decoded rust data to the event type.
Sourcefn tokenize_body(&self) -> Self::DataToken<'_>
fn tokenize_body(&self) -> Self::DataToken<'_>
Tokenize the event’s non-indexed parameters.
Sourcefn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
Encode the topics of this event into the given buffer. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the ABI-encoded dynamic data in bytes.
Sourcefn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data_to(&self, out: &mut Vec<u8>)
ABI-encode the dynamic data of this event into the given buffer.
Sourcefn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
Encode the topics of this event into a fixed-size array. Read more
Sourcefn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>
fn decode_topics<I, D>( topics: I, ) -> Result<<Self::TopicList as SolType>::RustType, Error>
Decode the topics of this event from the given data.
Sourcefn abi_decode_data<'a>(
data: &'a [u8],
validate: bool,
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data<'a>( data: &'a [u8], validate: bool, ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer.
Sourcefn decode_raw_log<I, D>(
topics: I,
data: &[u8],
validate: bool,
) -> Result<Self, Error>
fn decode_raw_log<I, D>( topics: I, data: &[u8], validate: bool, ) -> Result<Self, Error>
Decode the event from the given log info.
Sourceimpl Stream for TransferBatch
impl Stream for TransferBatch
async fn stream( &self, queue: &Client, network: &NetworkKind, ) -> Result<(), PropagateError>
Sourceimpl<'__s> ToSchema<'__s> for TransferBatch
impl<'__s> ToSchema<'__s> for TransferBatch
impl Eq for TransferBatch
impl StructuralPartialEq for TransferBatch