pub struct TransferSingle {
pub operator: Address,
pub from: Address,
pub to: Address,
pub id: U256,
pub value: U256,
}Expand description
Event with signature TransferSingle(address,address,address,uint256,uint256) and selector 0xc3d58168c5ae7397731d063d5bbf3d657854427343f4c083240f7aacaa2d0f62.
event TransferSingle(address operator, address from, address to, uint256 id, uint256 value);Fields
operator: Addressfrom: Addressto: Addressid: U256value: U256Trait Implementations
Sourceimpl Clone for TransferSingle
impl Clone for TransferSingle
Sourcefn clone(&self) -> TransferSingle
fn clone(&self) -> TransferSingle
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransferSingle
impl Debug for TransferSingle
Sourceimpl<'de> Deserialize<'de> for TransferSingle
impl<'de> Deserialize<'de> for TransferSingle
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Emit for TransferSingle
impl Emit for TransferSingle
async fn emit( &self, queue: &Client, network: &NetworkKind, ) -> Result<(), PropagateError>
Sourceimpl Hash for TransferSingle
impl Hash for TransferSingle
Sourceimpl Insert for TransferSingle
impl Insert for TransferSingle
Sourceimpl PartialEq for TransferSingle
impl PartialEq for TransferSingle
Sourceimpl Serialize for TransferSingle
impl Serialize for TransferSingle
Sourceimpl SolEvent for TransferSingle
impl SolEvent for TransferSingle
Sourceconst SIGNATURE: &'static str = "TransferSingle(address,address,address,uint256,uint256)"
const SIGNATURE: &'static str = "TransferSingle(address,address,address,uint256,uint256)"
The event’s ABI signature. Read more
Sourceconst SIGNATURE_HASH: B256
const SIGNATURE_HASH: B256
The event’s ABI signature hash, or selector:
keccak256(SIGNATURE) Read moreSourcetype DataTuple<'a> = (Address, Address, Address, Uint<256>, Uint<256>)
type DataTuple<'a> = (Address, Address, Address, Uint<256>, Uint<256>)
The underlying tuple type which represents this event’s non-indexed
parameters. These parameters are ABI encoded and included in the log
body. Read more
Sourcetype DataToken<'a> = <<TransferSingle as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
type DataToken<'a> = <<TransferSingle as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
The
TokenSeq type corresponding to the tuple.Sourcetype TopicList = (FixedBytes<32>,)
type TopicList = (FixedBytes<32>,)
The underlying tuple type which represents this event’s topics. Read more
Sourcefn new(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Self
fn new( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Self
Convert decoded rust data to the event type.
Sourcefn tokenize_body(&self) -> Self::DataToken<'_>
fn tokenize_body(&self) -> Self::DataToken<'_>
Tokenize the event’s non-indexed parameters.
Sourcefn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
Encode the topics of this event into the given buffer. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the ABI-encoded dynamic data in bytes.
Sourcefn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data_to(&self, out: &mut Vec<u8>)
ABI-encode the dynamic data of this event into the given buffer.
Sourcefn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
Encode the topics of this event into a fixed-size array. Read more
Sourcefn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>
fn decode_topics<I, D>( topics: I, ) -> Result<<Self::TopicList as SolType>::RustType, Error>
Decode the topics of this event from the given data.
Sourcefn abi_decode_data<'a>(
data: &'a [u8],
validate: bool,
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data<'a>( data: &'a [u8], validate: bool, ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer.
Sourcefn decode_raw_log<I, D>(
topics: I,
data: &[u8],
validate: bool,
) -> Result<Self, Error>
fn decode_raw_log<I, D>( topics: I, data: &[u8], validate: bool, ) -> Result<Self, Error>
Decode the event from the given log info.
Sourceimpl Stream for TransferSingle
impl Stream for TransferSingle
async fn stream( &self, queue: &Client, network: &NetworkKind, ) -> Result<(), PropagateError>
Sourceimpl<'__s> ToSchema<'__s> for TransferSingle
impl<'__s> ToSchema<'__s> for TransferSingle
impl Eq for TransferSingle
impl StructuralPartialEq for TransferSingle