pub struct Withdraw {
pub sender: Address,
pub receiver: Address,
pub owner: Address,
pub assets: U256,
pub shares: U256,
}Expand description
Event with signature Withdraw(address,address,address,uint256,uint256) and selector 0xfbde797d201c681b91056529119e0b02407c7bb96a4a2c75c01fc9667232c8db.
event Withdraw(address sender, address receiver, address owner, uint256 assets, uint256 shares);Fields
sender: Addressreceiver: Addressowner: Addressassets: U256Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Withdraw
impl<'de> Deserialize<'de> for Withdraw
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Emit for Withdraw
impl Emit for Withdraw
async fn emit( &self, queue: &Client, network: &NetworkKind, ) -> Result<(), PropagateError>
Sourceimpl SolEvent for Withdraw
impl SolEvent for Withdraw
Sourceconst SIGNATURE: &'static str = "Withdraw(address,address,address,uint256,uint256)"
const SIGNATURE: &'static str = "Withdraw(address,address,address,uint256,uint256)"
The event’s ABI signature. Read more
Sourceconst SIGNATURE_HASH: B256
const SIGNATURE_HASH: B256
The event’s ABI signature hash, or selector:
keccak256(SIGNATURE) Read moreSourcetype DataTuple<'a> = (Address, Address, Address, Uint<256>, Uint<256>)
type DataTuple<'a> = (Address, Address, Address, Uint<256>, Uint<256>)
The underlying tuple type which represents this event’s non-indexed
parameters. These parameters are ABI encoded and included in the log
body. Read more
Sourcetype DataToken<'a> = <<Withdraw as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
type DataToken<'a> = <<Withdraw as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
The
TokenSeq type corresponding to the tuple.Sourcetype TopicList = (FixedBytes<32>,)
type TopicList = (FixedBytes<32>,)
The underlying tuple type which represents this event’s topics. Read more
Sourcefn new(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Self
fn new( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Self
Convert decoded rust data to the event type.
Sourcefn tokenize_body(&self) -> Self::DataToken<'_>
fn tokenize_body(&self) -> Self::DataToken<'_>
Tokenize the event’s non-indexed parameters.
Sourcefn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
Encode the topics of this event into the given buffer. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the ABI-encoded dynamic data in bytes.
Sourcefn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data_to(&self, out: &mut Vec<u8>)
ABI-encode the dynamic data of this event into the given buffer.
Sourcefn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
Encode the topics of this event into a fixed-size array. Read more
Sourcefn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>
fn decode_topics<I, D>( topics: I, ) -> Result<<Self::TopicList as SolType>::RustType, Error>
Decode the topics of this event from the given data.
Sourcefn abi_decode_data<'a>(
data: &'a [u8],
validate: bool,
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data<'a>( data: &'a [u8], validate: bool, ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer.
Sourcefn decode_raw_log<I, D>(
topics: I,
data: &[u8],
validate: bool,
) -> Result<Self, Error>
fn decode_raw_log<I, D>( topics: I, data: &[u8], validate: bool, ) -> Result<Self, Error>
Decode the event from the given log info.
Sourceimpl Stream for Withdraw
impl Stream for Withdraw
async fn stream( &self, queue: &Client, network: &NetworkKind, ) -> Result<(), PropagateError>
Sourceimpl<'__s> ToSchema<'__s> for Withdraw
impl<'__s> ToSchema<'__s> for Withdraw
impl Eq for Withdraw
impl StructuralPartialEq for Withdraw