ERC721Events

Enum ERC721Events 

pub enum ERC721Events {
    Transfer(Transfer),
    Approval(Approval),
    ApprovalForAll(ApprovalForAll),
}
Container for all the ERC721 events.

Variants



Transfer(Transfer)



Approval(Approval)



ApprovalForAll(ApprovalForAll)

Implementations

Source

impl ERC721Events

pub const SELECTORS: &'static [[u8; 32]]

All the selectors of this enum.

Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.

Prefer using SolInterface methods instead.