pub struct ApprovalForAll {
pub owner: Address,
pub operator: Address,
pub approved: bool,
}Expand description
Event with signature ApprovalForAll(address,address,bool) and selector 0x17307eab39ab6107e8899845ad3d59bd9653f200f220920489ca2b5937696c31.
event ApprovalForAll(address owner, address operator, bool approved);Fields
owner: Addressoperator: Addressapproved: boolTrait Implementations
Sourceimpl Clone for ApprovalForAll
impl Clone for ApprovalForAll
Sourcefn clone(&self) -> ApprovalForAll
fn clone(&self) -> ApprovalForAll
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ApprovalForAll
impl Debug for ApprovalForAll
Sourceimpl<'de> Deserialize<'de> for ApprovalForAll
impl<'de> Deserialize<'de> for ApprovalForAll
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Emit for ApprovalForAll
impl Emit for ApprovalForAll
async fn emit( &self, queue: &Client, network: &NetworkKind, ) -> Result<(), PropagateError>
Sourceimpl Hash for ApprovalForAll
impl Hash for ApprovalForAll
Sourceimpl Insert for ApprovalForAll
impl Insert for ApprovalForAll
Sourceimpl PartialEq for ApprovalForAll
impl PartialEq for ApprovalForAll
Sourceimpl Serialize for ApprovalForAll
impl Serialize for ApprovalForAll
Sourceimpl SolEvent for ApprovalForAll
impl SolEvent for ApprovalForAll
Sourceconst SIGNATURE: &'static str = "ApprovalForAll(address,address,bool)"
const SIGNATURE: &'static str = "ApprovalForAll(address,address,bool)"
The event’s ABI signature. Read more
Sourceconst SIGNATURE_HASH: B256
const SIGNATURE_HASH: B256
The event’s ABI signature hash, or selector:
keccak256(SIGNATURE) Read moreSourcetype DataTuple<'a> = (Address, Address, Bool)
type DataTuple<'a> = (Address, Address, Bool)
The underlying tuple type which represents this event’s non-indexed
parameters. These parameters are ABI encoded and included in the log
body. Read more
Sourcetype DataToken<'a> = <<ApprovalForAll as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
type DataToken<'a> = <<ApprovalForAll as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
The
TokenSeq type corresponding to the tuple.Sourcetype TopicList = (FixedBytes<32>,)
type TopicList = (FixedBytes<32>,)
The underlying tuple type which represents this event’s topics. Read more
Sourcefn new(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Self
fn new( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Self
Convert decoded rust data to the event type.
Sourcefn tokenize_body(&self) -> Self::DataToken<'_>
fn tokenize_body(&self) -> Self::DataToken<'_>
Tokenize the event’s non-indexed parameters.
Sourcefn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
Encode the topics of this event into the given buffer. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the ABI-encoded dynamic data in bytes.
Sourcefn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data_to(&self, out: &mut Vec<u8>)
ABI-encode the dynamic data of this event into the given buffer.
Sourcefn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
Encode the topics of this event into a fixed-size array. Read more
Sourcefn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>
fn decode_topics<I, D>( topics: I, ) -> Result<<Self::TopicList as SolType>::RustType, Error>
Decode the topics of this event from the given data.
Sourcefn abi_decode_data<'a>(
data: &'a [u8],
validate: bool,
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data<'a>( data: &'a [u8], validate: bool, ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer.
Sourcefn decode_raw_log<I, D>(
topics: I,
data: &[u8],
validate: bool,
) -> Result<Self, Error>
fn decode_raw_log<I, D>( topics: I, data: &[u8], validate: bool, ) -> Result<Self, Error>
Decode the event from the given log info.
Sourceimpl Stream for ApprovalForAll
impl Stream for ApprovalForAll
async fn stream( &self, queue: &Client, network: &NetworkKind, ) -> Result<(), PropagateError>
Sourceimpl<'__s> ToSchema<'__s> for ApprovalForAll
impl<'__s> ToSchema<'__s> for ApprovalForAll
impl Eq for ApprovalForAll
impl StructuralPartialEq for ApprovalForAll