pub struct AuthorizedOperator {
pub operator: Address,
pub holder: Address,
}Expand description
Event with signature AuthorizedOperator(address,address) and selector 0xf4caeb2d6ca8932a215a353d0703c326ec2d81fc68170f320eb2ab49e9df61f9.
event AuthorizedOperator(address operator, address holder);Fields
operator: Addressholder: AddressTrait Implementations
Sourceimpl Clone for AuthorizedOperator
impl Clone for AuthorizedOperator
Sourcefn clone(&self) -> AuthorizedOperator
fn clone(&self) -> AuthorizedOperator
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuthorizedOperator
impl Debug for AuthorizedOperator
Sourceimpl<'de> Deserialize<'de> for AuthorizedOperator
impl<'de> Deserialize<'de> for AuthorizedOperator
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Emit for AuthorizedOperator
impl Emit for AuthorizedOperator
async fn emit( &self, queue: &Client, network: &NetworkKind, ) -> Result<(), PropagateError>
Sourceimpl Hash for AuthorizedOperator
impl Hash for AuthorizedOperator
Sourceimpl Insert for AuthorizedOperator
impl Insert for AuthorizedOperator
Sourceimpl PartialEq for AuthorizedOperator
impl PartialEq for AuthorizedOperator
Sourceimpl Serialize for AuthorizedOperator
impl Serialize for AuthorizedOperator
Sourceimpl SolEvent for AuthorizedOperator
impl SolEvent for AuthorizedOperator
Sourceconst SIGNATURE: &'static str = "AuthorizedOperator(address,address)"
const SIGNATURE: &'static str = "AuthorizedOperator(address,address)"
The event’s ABI signature. Read more
Sourceconst SIGNATURE_HASH: B256
const SIGNATURE_HASH: B256
The event’s ABI signature hash, or selector:
keccak256(SIGNATURE) Read moreSourcetype DataTuple<'a> = (Address, Address)
type DataTuple<'a> = (Address, Address)
The underlying tuple type which represents this event’s non-indexed
parameters. These parameters are ABI encoded and included in the log
body. Read more
Sourcetype DataToken<'a> = <<AuthorizedOperator as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
type DataToken<'a> = <<AuthorizedOperator as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
The
TokenSeq type corresponding to the tuple.Sourcetype TopicList = (FixedBytes<32>,)
type TopicList = (FixedBytes<32>,)
The underlying tuple type which represents this event’s topics. Read more
Sourcefn new(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Self
fn new( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Self
Convert decoded rust data to the event type.
Sourcefn tokenize_body(&self) -> Self::DataToken<'_>
fn tokenize_body(&self) -> Self::DataToken<'_>
Tokenize the event’s non-indexed parameters.
Sourcefn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
Encode the topics of this event into the given buffer. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the ABI-encoded dynamic data in bytes.
Sourcefn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data_to(&self, out: &mut Vec<u8>)
ABI-encode the dynamic data of this event into the given buffer.
Sourcefn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
Encode the topics of this event into a fixed-size array. Read more
Sourcefn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>
fn decode_topics<I, D>( topics: I, ) -> Result<<Self::TopicList as SolType>::RustType, Error>
Decode the topics of this event from the given data.
Sourcefn abi_decode_data<'a>(
data: &'a [u8],
validate: bool,
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data<'a>( data: &'a [u8], validate: bool, ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer.
Sourcefn decode_raw_log<I, D>(
topics: I,
data: &[u8],
validate: bool,
) -> Result<Self, Error>
fn decode_raw_log<I, D>( topics: I, data: &[u8], validate: bool, ) -> Result<Self, Error>
Decode the event from the given log info.
Sourceimpl Stream for AuthorizedOperator
impl Stream for AuthorizedOperator
async fn stream( &self, queue: &Client, network: &NetworkKind, ) -> Result<(), PropagateError>
Sourceimpl<'__s> ToSchema<'__s> for AuthorizedOperator
impl<'__s> ToSchema<'__s> for AuthorizedOperator
impl Eq for AuthorizedOperator
impl StructuralPartialEq for AuthorizedOperator